@@ -37,15 +37,15 @@ typedef struct _CPUFreqSysfs      CPUFreqSysfs;
 typedef struct _CPUFreqSysfsClass CPUFreqSysfsClass;
 
 struct _CPUFreqSysfs {
-	   CPUFreq parent;
+        CPUFreq parent;
 };
 
 struct _CPUFreqSysfsClass {
-	   CPUFreqClass parent_class;
+        CPUFreqClass parent_class;
 };
 
 
-GType         cpufreq_sysfs_get_type ();
-CPUFreqSysfs *cpufreq_sysfs_new      ();
+GType         cpufreq_sysfs_get_type (void) G_GNUC_CONST;
+CPUFreqSysfs *cpufreq_sysfs_new      (void);
 
 #endif /* __CPUFREQ_SYSFS_H__ */
